@@ -18,7 +18,8 @@
 */
 
 #include "syntaxhighlighterbase.h"
-
+#include <QRegularExpressionMatch>
+#include <QDebug>
 using namespace KPIMTextEdit;
 SyntaxHighlighterBase::SyntaxHighlighterBase(QTextDocument *doc)
     : QSyntaxHighlighter(doc)
@@ -34,12 +35,18 @@ SyntaxHighlighterBase::~SyntaxHighlighterBase()
 void SyntaxHighlighterBase::highlightBlock(const QString &text)
 {
     Q_FOREACH (const Rule &rule, m_rules) {
-        const QRegExp expression(rule.pattern);
-        int index = expression.indexIn(text);
-        int length = 0;
-        while (index >= 0 && (length = expression.matchedLength()) > 0) {
-            setFormat(index, length, rule.format);
-            index = expression.indexIn(text, index + length);
+        const QRegularExpression expression(rule.pattern);
+        if (!expression.isValid()) {
+             const QString errorString = expression.errorString();
+             qDebug() << "expression is invalid, pattern:" << rule.pattern << " error :" << errorString;
+        }
+        QRegularExpressionMatch match = expression.match(text);
+
+        int index = match.capturedStart();
+        while (index >= 0 && match.hasMatch()) {
+            setFormat(index, match.capturedLength(), rule.format);
+            match = expression.match(text, index + match.capturedLength());
+            index = match.capturedStart();
         }
     }
 }
