@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -106,8 +106,8 @@ public:
         backgroundColor->setEnabled(false);
         q->connect(useBackgroundColor, &QCheckBox::toggled, backgroundColor, &KColorButton::setEnabled);
         QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-        connect(buttonBox, SIGNAL(accepted()), q, SLOT(accept()));
-        connect(buttonBox, SIGNAL(rejected()), q, SLOT(reject()));
+        connect(buttonBox, &QDialogButtonBox::accepted, q, &QDialog::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, q, &QDialog::reject);
 
         mainLayout->addWidget(page);
         mainLayout->addWidget(buttonBox);
